import request from '@/router/axios'

// 获取出库、入库，库存，收入，支出
export function getHeadStatAPI() {
  return request({
    url: '/invtory/home/getHeadStat',
    method: 'get'
  })
}

// 获取销售统
export function getSaleStatAPI(year) {
  return request({
    url: '/invtory/home/getSaleStat/' + year,
    method: 'get'
  })
}

// 获取客户排名
export function getCustRankAPI() {
  return request({
    url: '/invtory/home/getCustRank',
    method: 'get'
  })
}

// 获取消息
export function getMessageAPI() {
  return request({
    url: '/invtory/home/getMessage',
    method: 'get'
  })
}

// 今日统计
export const tabsOptionToday = {
  span: 6,
  data: [
    {
      // click: function (item) {
      //   alert(JSON.stringify(item));
      // },
      title: '出库数量',
      subtitle: '今日',
      count: 7823,
      allcount: 324324,
      text: '总计',
      color: '#ed8719',
      key: '管'
    },
    {
      // prop: "shop",
      title: '入库数',
      subtitle: '今日',
      count: 4384,
      allcount: 232154,
      text: '总计',
      color: 'rgb(230, 71, 88)',
      key: '理'
    },
    {
      // prop: "member",
      title: '销售额',
      subtitle: '今日',
      count: 8596,
      allcount: 675765,
      text: '总计',
      color: 'rgb(27, 201, 142)',
      key: '系'
    },
    {
      // prop: "member",
      title: '库存总数',
      subtitle: '今日',
      count: 2483274932,
      // allcount: 7565,
      text: '总计',
      color: '#08afc2',
      key: '统'
    },
  ]
}

// 商品折线图
export const godsChart = {
  width: '95%',
  title: {
    text: `{a|销售统计} {b|单位：片}`,
    // subtext: '月度统计表',
    subtextStyle: {  //小标题样式
      color: '#ff4536'
    },
    textStyle: {
      rich: {
        a: {
          fontSize:18,
          color: '#0d95e1',
          fontWeight:900,
        },
        b: {
          fontSize:14,
          fontFamily: 'SimHei',
          color: 'black',
          // textAlign: 'justify', 
          // paddingBottom: 0,
        }
      }
    }  
  },
  tooltip: {
    trigger: 'axis'
  },
  // 图例组件
  legend: {
    // orient: 'vertical',
    // x: 'right',
    // y: 'center',
    bottom: '0',
    right: '0',
    // top: '0',
    data: ['入库数', '出库数']
  },
  grid: {
    left: '3%',
    right: '2%',
    bottom: '8%',
    containLabel: true
  },
  xAxis: {
    type: 'category',
    // boundaryGap: false,
    // axisLabel: {  //x轴刻度数值颜色
    //   // rotate: 10, //旋转x轴的文字
    //   interval:1, //x轴每个项的距离  修改数据显示的个数
    // },
    // data: ['一月', '二月', '三月', '四月', '五月', '六月', '七月', '八月', '九月', '十月', '十一月', '十二月']
    data: ['1月', '2月', '3月', '4月', '5月', '6月', '7月', '8月', '9月', '10月', '11月', '12月']
  },
  yAxis: {
    type: 'value'
  },
  series: [
    {
      name: '入库数',
      type: 'bar',
      stack: '单元式本月销售量',
      data: [100, 110, 120, 130, 140, 150, 160, 170, 180, 190, 200, 210]
    },
    {
      name: '出库数',
      type: 'bar',
      stack: '公寓式本月销售量',
      data: [155, 125, 130, 150, 120, 170, 180, 150, 160, 180, 220, 250]
    },
    // {
    //   name: '复式',
    //   type: 'bar',
    //   stack: '复式本月销售量',
    //   data: [110, 110, 120, 150, 130, 150, 160, 170, 200, 210, 180, 230]
    // },
    // {
    //   name: '跃层式',
    //   type: 'bar',
    //   stack: '跃层式本月销售量',
    //   data: [110, 110, 120, 150, 130, 150, 160, 170, 200, 210, 180, 230]
    // },
    // {
    //   name: '别墅',
    //   type: 'bar',
    //   stack: '别墅本月销售量',
    //   data: [110, 110, 120, 150, 130, 150, 160, 170, 200, 210, 180, 230]
    // },
  ]
}

// 饼图
export const salesChart = {
  color: ['#0d95e1'],
  width: '95%',
  title: {
    // text: '销售额统计 单位：万元',
    text: `{a|收支统计} {b|单位：万元}`,
    // subtext: '月度统计表',
    subtextStyle: {  //小标题样式
      color: '#ff4536'
    },
    textStyle: {
      rich: {
        a: {
          fontSize:18,
          color: '#0d95e1',
          fontWeight:900,
        },
        b: {
          fontSize:14,
          fontFamily: 'SimHei',
          color: 'black',
          // textAlign: 'justify', 
          paddingBottom: 0,
        }
      }
    },
  },
  // title: {
  //   top: 10,
  //   text: '库存数量比',
  //   x: 'center'
  // },
  tooltip: {
    trigger: 'item', // 在图形上才会触发提示
    formatter: '{a} <br/>{b} : {c} ({d}%)' // 提示的文字显示的格式
    // a: 系列名
    // b: 数据名
    // c: 数值
    // d: 百分比 (只有饼状图生效)
  },
  color: ['#5885e8', '#13cfd5', '#00ce68', '#ff9565'], // 系列颜色
  legend: { // 图例组件
    bottom: 10,
    left: 'center',
    data: ['支出', '收入'] // 每个部分对应的数据名(要和series里name对应)
  },
  // toolbox: { // 工具箱
  //   show: true,
  //   x: 'center',
  //   top: 35,
  //   feature: {
  //     mark: { show: true },
  //     dataView: { show: true, readOnly: false },
  //     magicType: {
  //       show: true,
  //       type: ['pie', 'funnel'],
  //       option: {
  //         funnel: {
  //           x: '25%',
  //           width: '50%',
  //           funnelAlign: 'left',
  //           max: 1548
  //         }
  //       }
  //     },
  //     restore: { show: true },
  //     saveAsImage: { show: true }
  //   }
  // },
  series: [
    {
      name: '库存',
      type: 'pie',
      radius: '70%',
      center: ['50%', '45%'],
      itemStyle: {
        borderRadius: 10,
        borderColor: '#fff',
        borderWidth: 2
      },
      label: {
        formatter: '{a} \n{b} : {c} ({d}%)',
        backgroundColor: '#F6F8FC',
        borderColor: '#8C8D8E',
        lineHeight: 22,
        borderRadius: 4,
        rich: {
          a: {
            color: '#6E7079',
            lineHeight: 22,
            align: 'center'
          },
          b: {
            borderColor: '#8C8D8E',
            width: '100%',
            borderWidth: 1,
            height: 0
          },
          // c: {
          //   color: '#4C5058',
          //   fontSize: 14,
          //   fontWeight: 'bold',
          //   lineHeight: 33
          // },
          // d: {
          //   color: '#fff',
          //   backgroundColor: '#4C5058',
          //   padding: [3, 4],
          //   borderRadius: 4
          // }
        }
      },
      data: [
        { value: 300, name: '支出' },
        { value: 100, name: '收入' }
      ]
    }
  ]
  // title: {
  //   // text: '销售额统计 单位：万元',
  //   text: `{a|账户余额} {b|单位：万元}`,
  //   subtext: '月度统计表',
  //   subtextStyle: {  //小标题样式
  //     color: '#ff4536'
  //   },
  //   textStyle: {
  //     rich: {
  //       a: {
  //         fontSize:18,
  //         color: '#0d95e1',
  //         fontWeight:900,
  //       },
  //       b: {
  //         fontSize:14,
  //         fontFamily: 'SimHei',
  //         color: 'black',
  //         // textAlign: 'justify', 
  //         paddingBottom: 0,
  //       }
  //     }
  //   },
  // },
  // tooltip: {},
  // grid: {
  //   left: '3%',
  //   right: '2%',
  //   bottom: '1%',
  //   containLabel: true
  // },
  // xAxis: {
  //   type: 'category',
  //   axisLabel: {  //x轴刻度数值颜色
  //     // rotate: 10, //旋转x轴的文字
  //     interval:1, //x轴每个项的距离  修改数据显示的个数
  //   },
  //   data: ['1月', '2月', '3月', '4月', '5月', '6月', '7月', '8月', '9月', '10月', '11月', '12月']
  // },
  // yAxis: { type: 'value' },
  // series: [
  //   {
  //     name: '销量',
  //     type: 'bar',
  //     data: [550,100,800,700,650,700,550,100,800,700,650,700],
  //     // data: [],
  //   }
  // ]
}

